@@ -7,6 +7,7 @@ from threading import Thread
 from typing import Optional
 import websocket
 
+from .camera.structures import RayPacket
 from .events import EventLoopManager
 from .rustplus_proto import AppMessage, AppRequest
 from ..structures import RustChatMessage
@@ -185,12 +186,14 @@ class RustWebsocket(websocket.WebSocket):
             self.remote.ignored_responses.remove(app_message.response.seq)
             return
 
-        prefix = self.get_prefix(str(app_message.broadcast.teamMessage.message.message))
+        prefix = self.get_prefix(
+            str(app_message.broadcast.newTeamMessage.message.message)
+        )
 
         if prefix is not None:
             # This means it is a command
 
-            message = RustChatMessage(app_message.broadcast.teamMessage.message)
+            message = RustChatMessage(app_message.broadcast.newTeamMessage.message)
 
             self.remote.command_handler.run_command(message, prefix)
 
@@ -203,6 +206,12 @@ class RustWebsocket(websocket.WebSocket):
                 self.server_id,
             )
 
+        elif self.is_camera_broadcast(app_message):
+            if self.remote.camera_manager is not None:
+                self.remote.camera_manager.add_packet(
+                    RayPacket(app_message.broadcast.cameraRays)
+                )
+
         elif self.is_team_broadcast(app_message):
             # This means that the team of the current player has changed
             self.remote.event_handler.run_team_event(app_message, self.server_id)
@@ -210,8 +219,8 @@ class RustWebsocket(websocket.WebSocket):
         elif self.is_message(app_message):
             # This means that a message has been sent to the team chat
 
-            steam_id = int(app_message.broadcast.teamMessage.message.steamId)
-            message = str(app_message.broadcast.teamMessage.message.message)
+            steam_id = int(app_message.broadcast.newTeamMessage.message.steamId)
+            message = str(app_message.broadcast.newTeamMessage.message.message)
 
             # Conversation API
             if self.remote.conversation_factory.has_conversation(steam_id):
@@ -267,7 +276,11 @@ class RustWebsocket(websocket.WebSocket):
 
     @staticmethod
     def is_message(app_message) -> bool:
-        return str(app_message.broadcast.teamMessage.message.message) != ""
+        return str(app_message.broadcast.newTeamMessage.message.message) != ""
+
+    @staticmethod
+    def is_camera_broadcast(app_message) -> bool:
+        return app_message.broadcast.HasField("cameraRays")
 
     @staticmethod
     def is_entity_broadcast(app_message) -> bool:
@@ -277,7 +290,7 @@ class RustWebsocket(websocket.WebSocket):
     def is_team_broadcast(app_message) -> bool:
         return str(app_message.broadcast.teamChanged) != ""
 
-    async def _retry_failed_request(self, app_request: AppRequest):
+    async def _retry_failed_request(self, app_request: AppRequest) -> None:
         """
         Resends an AppRequest to the server if it has failed
         """
